summaryrefslogtreecommitdiffstats
path: root/librss/article.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /librss/article.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'librss/article.h')
-rw-r--r--librss/article.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/librss/article.h b/librss/article.h
index 865a6bbc..d6c4a937 100644
--- a/librss/article.h
+++ b/librss/article.h
@@ -36,7 +36,7 @@ namespace RSS
/**
* A list of articles.
*/
- typedef QValueList<Article> List;
+ typedef TQValueList<Article> List;
/**
* Default constructor.
@@ -51,10 +51,10 @@ namespace RSS
/**
* Constructs an Article from a piece of RSS markup.
* @param node A QDomNode which references the DOM leaf to be used
* for constructing the Article.
*/
- Article(const QDomNode &node);
+ Article(const TQDomNode &node);
/**
* Assignment operator.
@@ -86,10 +86,10 @@ namespace RSS
/**
* RSS 0.90 and upwards
* @return The headline of this article, or QString::null if
* no headline was available.
*/
- QString title() const;
+ TQString title() const;
/**
* RSS 0.90 and upwards
@@ -102,20 +102,20 @@ namespace RSS
/**
* RSS 0.91 and upwards
* @return A story synopsis, or QString::null if no description
* was available.
*/
- QString description() const;
+ TQString description() const;
/**
* RSS 2.0 and upwards
* @return An article GUID (globally unique identifier).
*/
- QString guid() const;
+ TQString guid() const;
/**
* RSS 2.0 and upwards
* @return If this article GUID is permalink. Has no meaning when guid() is QString::null.
*/
bool guidIsPermaLink() const;
@@ -123,7 +123,7 @@ namespace RSS
* RSS 2.0 and upwards
* @return The date when the article was published.
*/
- const QDateTime &pubDate() const;
+ const TQDateTime &pubDate() const;
/**
* @param parent The parent widget for the KURLLabel.
@@ -132,14 +132,14 @@ namespace RSS
* This makes building a user-interface which contains the
* information in this Article object more convenient.
* The returned KURLLabel's caption will be the title(), clicking
- * on it will emit the URL link(), and it has a QToolTip attached
+ * on it will emit the URL link(), and it has a TQToolTip attached
* to it which displays the description() (in case it has one,
* if there is no description, the URL which the label links to
* will be used).
* Note that you have to delete the KURLLabel object returned by
* this method yourself.
*/
- KURLLabel *widget(QWidget *parent = 0, const char *name = 0) const;
+ KURLLabel *widget(TQWidget *parent = 0, const char *name = 0) const;
private:
struct Private;
@@ -51,10 +51,10 @@ namespace RSS
/**
* Constructs an Article from a piece of RSS markup.
- * @param node A QDomNode which references the DOM leaf to be used
+ * @param node A TQDomNode which references the DOM leaf to be used
* for constructing the Article.
*/
@@ -86,10 +86,10 @@ namespace RSS
/**
* RSS 0.90 and upwards
- * @return The headline of this article, or QString::null if
+ * @return The headline of this article, or TQString::null if
* no headline was available.
*/
@@ -102,20 +102,20 @@ namespace RSS
/**
* RSS 0.91 and upwards
- * @return A story synopsis, or QString::null if no description
+ * @return A story synopsis, or TQString::null if no description
* was available.
*/
@@ -102,20 +102,20 @@ namespace RSS
/**
* RSS 2.0 and upwards
- * @return If this article GUID is permalink. Has no meaning when guid() is QString::null.
+ * @return If this article GUID is permalink. Has no meaning when guid() is TQString::null.
*/
bool guidIsPermaLink() const;